Red Rooster Polska - Wciągarki, Wciągniki, Wagi Tensometryczne.
Author: Red Rooster Industrial (UK) Ltd Sp. z o.o. Oddział w Polsce
Description: Producent Nowoczesnych Urządzeń Dźwigowych takich jak Wciągarki (pneumatyczne, ręczne), Wciągniki, Nawijarki Lin oraz Wagi Tensometryczne.
Keywords: wciągniki, wciągnik, wciągarki, cnc, obróbka skrawaniem, frezowanie, toczenie, Wciągarki łańcuchowe, wciągniki łańcuchowe, wagi przemysłowe, tensometry, wciągarki pneumatyczne, wciągarka, wagi tensometryczne,

Red Rooster Poland Sp. z o.o.
ul. Grabska 11, 32-005 Niepołomice, woj. małopolskie, Polska
tel: +48 12 27 85 666
e-mail: biuro@redrooster.com
50.032892, 20.191637
NIP: 6832085719, REGON:361257067
Sąd Rejonowy dla Krakowa- Śródmieścia,
XII Wydział Gospodarczy Krajowego Rejestru Sądowego
KRS 0000552395
Wysokość kapitału zakładowego: 2 305 000,00 PLN

# Skontaktuj
się z nami

Zmień obrazek
Treść wiadomości
WYŚLIJ